import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface AlertChannelConfig extends cdktf.TerraformMetaArguments {
    /**
     * (Required) The name of the channel.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/alert_channel.html#name AlertChannel#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * (Required) The type of channel. One of: (slack, user, victorops, webhook, email, opsgenie, pagerduty).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/alert_channel.html#type AlertChannel#type}
     *
     * @stability stable
     */
    readonly type: string;
    /**
     * config block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/alert_channel.html#config AlertChannel#config}
     *
     * @stability stable
     */
    readonly config?: AlertChannelConfigA;
}
/**
 * @stability stable
 */
export interface AlertChannelConfigA {
    /**
     * The API key for integrating with OpsGenie.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/alert_channel.html#api_key AlertChannel#api_key}
     *
     * @stability stable
     */
    readonly apiKey?: string;
    /**
     * Specifies an authentication password for use with a channel. Supported by the webhook channel type.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/alert_channel.html#auth_password AlertChannel#auth_password}
     *
     * @stability stable
     */
    readonly authPassword?: string;
    /**
     * Specifies an authentication method for use with a channel.
     *
     * Supported by the webhook channel type. Only HTTP basic authentication is currently supported via the value BASIC.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/alert_channel.html#auth_type AlertChannel#auth_type}
     *
     * @stability stable
     */
    readonly authType?: string;
    /**
     * Specifies an authentication username for use with a channel. Supported by the webhook channel type.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/alert_channel.html#auth_username AlertChannel#auth_username}
     *
     * @stability stable
     */
    readonly authUsername?: string;
    /**
     * The base URL of the webhook destination.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/alert_channel.html#base_url AlertChannel#base_url}
     *
     * @stability stable
     */
    readonly baseUrl?: string;
    /**
     * The Slack channel to send notifications to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/alert_channel.html#channel AlertChannel#channel}
     *
     * @stability stable
     */
    readonly channel?: string;
    /**
     * A map of key/value pairs that represents extra HTTP headers to be sent along with the webhook payload.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/alert_channel.html#headers AlertChannel#headers}
     *
     * @stability stable
     */
    readonly headers?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Use instead of headers if the desired payload is more complex than a list of key/value pairs (e.g. a set of headers that makes use of nested objects). The value provided should be a valid JSON string with escaped double quotes. Conflicts with headers.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/alert_channel.html#headers_string AlertChannel#headers_string}
     *
     * @stability stable
     */
    readonly headersString?: string;
    /**
     * true or false.
     *
     * Flag for whether or not to attach a JSON document containing information about the associated alert to the email that is sent to recipients.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/alert_channel.html#include_json_attachment AlertChannel#include_json_attachment}
     *
     * @stability stable
     */
    readonly includeJsonAttachment?: string;
    /**
     * The key for integrating with VictorOps.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/alert_channel.html#key AlertChannel#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * A map of key/value pairs that represents the webhook payload. Must provide payload_type if setting this argument.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/alert_channel.html#payload AlertChannel#payload}
     *
     * @stability stable
     */
    readonly payload?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Use instead of payload if the desired payload is more complex than a list of key/value pairs (e.g. a payload that makes use of nested objects). The value provided should be a valid JSON string with escaped double quotes. Conflicts with payload.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/alert_channel.html#payload_string AlertChannel#payload_string}
     *
     * @stability stable
     */
    readonly payloadString?: string;
    /**
     * Can either be application/json or application/x-www-form-urlencoded. The payload_type argument is required if payload is set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/alert_channel.html#payload_type AlertChannel#payload_type}
     *
     * @stability stable
     */
    readonly payloadType?: string;
    /**
     * A set of recipients for targeting notifications. Multiple values are comma separated.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/alert_channel.html#recipients AlertChannel#recipients}
     *
     * @stability stable
     */
    readonly recipients?: string;
    /**
     * The data center region to store your data. Valid values are US and EU. Default is US.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/alert_channel.html#region AlertChannel#region}
     *
     * @stability stable
     */
    readonly region?: string;
    /**
     * The route key for integrating with VictorOps.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/alert_channel.html#route_key AlertChannel#route_key}
     *
     * @stability stable
     */
    readonly routeKey?: string;
    /**
     * Specifies the service key for integrating with Pagerduty.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/alert_channel.html#service_key AlertChannel#service_key}
     *
     * @stability stable
     */
    readonly serviceKey?: string;
    /**
     * A set of tags for targeting notifications. Multiple values are comma separated.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/alert_channel.html#tags AlertChannel#tags}
     *
     * @stability stable
     */
    readonly tags?: string;
    /**
     * A set of teams for targeting notifications. Multiple values are comma separated.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/alert_channel.html#teams AlertChannel#teams}
     *
     * @stability stable
     */
    readonly teams?: string;
    /**
     * Your organization's Slack URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/alert_channel.html#url AlertChannel#url}
     *
     * @stability stable
     */
    readonly url?: string;
    /**
     * The user ID for use with the user channel type.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/alert_channel.html#user_id AlertChannel#user_id}
     *
     * @stability stable
     */
    readonly userId?: string;
}
export declare function alertChannelConfigAToTerraform(struct?: AlertChannelConfigAOutputReference | AlertChannelConfigA): any;
/**
 * @stability stable
 */
export declare class AlertChannelConfigAOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): AlertChannelConfigA | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: AlertChannelConfigA | undefined);
    private _apiKey?;
    /**
     * @stability stable
     */
    get apiKey(): string;
    /**
     * @stability stable
     */
    set apiKey(value: string);
    /**
     * @stability stable
     */
    resetApiKey(): void;
    /**
     * @stability stable
     */
    get apiKeyInput(): string | undefined;
    private _authPassword?;
    /**
     * @stability stable
     */
    get authPassword(): string;
    /**
     * @stability stable
     */
    set authPassword(value: string);
    /**
     * @stability stable
     */
    resetAuthPassword(): void;
    /**
     * @stability stable
     */
    get authPasswordInput(): string | undefined;
    private _authType?;
    /**
     * @stability stable
     */
    get authType(): string;
    /**
     * @stability stable
     */
    set authType(value: string);
    /**
     * @stability stable
     */
    resetAuthType(): void;
    /**
     * @stability stable
     */
    get authTypeInput(): string | undefined;
    private _authUsername?;
    /**
     * @stability stable
     */
    get authUsername(): string;
    /**
     * @stability stable
     */
    set authUsername(value: string);
    /**
     * @stability stable
     */
    resetAuthUsername(): void;
    /**
     * @stability stable
     */
    get authUsernameInput(): string | undefined;
    private _baseUrl?;
    /**
     * @stability stable
     */
    get baseUrl(): string;
    /**
     * @stability stable
     */
    set baseUrl(value: string);
    /**
     * @stability stable
     */
    resetBaseUrl(): void;
    /**
     * @stability stable
     */
    get baseUrlInput(): string | undefined;
    private _channel?;
    /**
     * @stability stable
     */
    get channel(): string;
    /**
     * @stability stable
     */
    set channel(value: string);
    /**
     * @stability stable
     */
    resetChannel(): void;
    /**
     * @stability stable
     */
    get channelInput(): string | undefined;
    private _headers?;
    /**
     * @stability stable
     */
    get headers(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set headers(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetHeaders(): void;
    /**
     * @stability stable
     */
    get headersInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _headersString?;
    /**
     * @stability stable
     */
    get headersString(): string;
    /**
     * @stability stable
     */
    set headersString(value: string);
    /**
     * @stability stable
     */
    resetHeadersString(): void;
    /**
     * @stability stable
     */
    get headersStringInput(): string | undefined;
    private _includeJsonAttachment?;
    /**
     * @stability stable
     */
    get includeJsonAttachment(): string;
    /**
     * @stability stable
     */
    set includeJsonAttachment(value: string);
    /**
     * @stability stable
     */
    resetIncludeJsonAttachment(): void;
    /**
     * @stability stable
     */
    get includeJsonAttachmentInput(): string | undefined;
    private _key?;
    /**
     * @stability stable
     */
    get key(): string;
    /**
     * @stability stable
     */
    set key(value: string);
    /**
     * @stability stable
     */
    resetKey(): void;
    /**
     * @stability stable
     */
    get keyInput(): string | undefined;
    private _payload?;
    /**
     * @stability stable
     */
    get payload(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set payload(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetPayload(): void;
    /**
     * @stability stable
     */
    get payloadInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _payloadString?;
    /**
     * @stability stable
     */
    get payloadString(): string;
    /**
     * @stability stable
     */
    set payloadString(value: string);
    /**
     * @stability stable
     */
    resetPayloadString(): void;
    /**
     * @stability stable
     */
    get payloadStringInput(): string | undefined;
    private _payloadType?;
    /**
     * @stability stable
     */
    get payloadType(): string;
    /**
     * @stability stable
     */
    set payloadType(value: string);
    /**
     * @stability stable
     */
    resetPayloadType(): void;
    /**
     * @stability stable
     */
    get payloadTypeInput(): string | undefined;
    private _recipients?;
    /**
     * @stability stable
     */
    get recipients(): string;
    /**
     * @stability stable
     */
    set recipients(value: string);
    /**
     * @stability stable
     */
    resetRecipients(): void;
    /**
     * @stability stable
     */
    get recipientsInput(): string | undefined;
    private _region?;
    /**
     * @stability stable
     */
    get region(): string;
    /**
     * @stability stable
     */
    set region(value: string);
    /**
     * @stability stable
     */
    resetRegion(): void;
    /**
     * @stability stable
     */
    get regionInput(): string | undefined;
    private _routeKey?;
    /**
     * @stability stable
     */
    get routeKey(): string;
    /**
     * @stability stable
     */
    set routeKey(value: string);
    /**
     * @stability stable
     */
    resetRouteKey(): void;
    /**
     * @stability stable
     */
    get routeKeyInput(): string | undefined;
    private _serviceKey?;
    /**
     * @stability stable
     */
    get serviceKey(): string;
    /**
     * @stability stable
     */
    set serviceKey(value: string);
    /**
     * @stability stable
     */
    resetServiceKey(): void;
    /**
     * @stability stable
     */
    get serviceKeyInput(): string | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): string;
    /**
     * @stability stable
     */
    set tags(value: string);
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): string | undefined;
    private _teams?;
    /**
     * @stability stable
     */
    get teams(): string;
    /**
     * @stability stable
     */
    set teams(value: string);
    /**
     * @stability stable
     */
    resetTeams(): void;
    /**
     * @stability stable
     */
    get teamsInput(): string | undefined;
    private _url?;
    /**
     * @stability stable
     */
    get url(): string;
    /**
     * @stability stable
     */
    set url(value: string);
    /**
     * @stability stable
     */
    resetUrl(): void;
    /**
     * @stability stable
     */
    get urlInput(): string | undefined;
    private _userId?;
    /**
     * @stability stable
     */
    get userId(): string;
    /**
     * @stability stable
     */
    set userId(value: string);
    /**
     * @stability stable
     */
    resetUserId(): void;
    /**
     * @stability stable
     */
    get userIdInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/newrelic/r/alert_channel.html newrelic_alert_channel}.
 *
 * @stability stable
 */
export declare class AlertChannel extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/newrelic/r/alert_channel.html newrelic_alert_channel} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: AlertChannelConfig);
    /**
     * @stability stable
     */
    get id(): string;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _type?;
    /**
     * @stability stable
     */
    get type(): string;
    /**
     * @stability stable
     */
    set type(value: string);
    /**
     * @stability stable
     */
    get typeInput(): string | undefined;
    private _config;
    /**
     * @stability stable
     */
    get config(): AlertChannelConfigAOutputReference;
    /**
     * @stability stable
     */
    putConfig(value: AlertChannelConfigA): void;
    /**
     * @stability stable
     */
    resetConfig(): void;
    /**
     * @stability stable
     */
    get configInput(): AlertChannelConfigA | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
