import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface SyntheticsAlertConditionConfig extends cdktf.TerraformMetaArguments {
    /**
     * Set whether to enable the alert condition. Defaults to true.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/synthetics_alert_condition.html#enabled SyntheticsAlertCondition#enabled}
     *
     * @stability stable
     */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
     * The ID of the Synthetics monitor to be referenced in the alert condition.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/synthetics_alert_condition.html#monitor_id SyntheticsAlertCondition#monitor_id}
     *
     * @stability stable
     */
    readonly monitorId: string;
    /**
     * The title of this condition.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/synthetics_alert_condition.html#name SyntheticsAlertCondition#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The ID of the policy where this condition should be used.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/synthetics_alert_condition.html#policy_id SyntheticsAlertCondition#policy_id}
     *
     * @stability stable
     */
    readonly policyId: number;
    /**
     * Runbook URL to display in notifications.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/synthetics_alert_condition.html#runbook_url SyntheticsAlertCondition#runbook_url}
     *
     * @stability stable
     */
    readonly runbookUrl?: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/newrelic/r/synthetics_alert_condition.html newrelic_synthetics_alert_condition}.
 *
 * @stability stable
 */
export declare class SyntheticsAlertCondition extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/newrelic/r/synthetics_alert_condition.html newrelic_synthetics_alert_condition} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: SyntheticsAlertConditionConfig);
    private _enabled?;
    /**
     * @stability stable
     */
    get enabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetEnabled(): void;
    /**
     * @stability stable
     */
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _monitorId?;
    /**
     * @stability stable
     */
    get monitorId(): string;
    /**
     * @stability stable
     */
    set monitorId(value: string);
    /**
     * @stability stable
     */
    get monitorIdInput(): string | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _policyId?;
    /**
     * @stability stable
     */
    get policyId(): number;
    /**
     * @stability stable
     */
    set policyId(value: number);
    /**
     * @stability stable
     */
    get policyIdInput(): number | undefined;
    private _runbookUrl?;
    /**
     * @stability stable
     */
    get runbookUrl(): string;
    /**
     * @stability stable
     */
    set runbookUrl(value: string);
    /**
     * @stability stable
     */
    resetRunbookUrl(): void;
    /**
     * @stability stable
     */
    get runbookUrlInput(): string | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
