import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface SyntheticsMonitorScriptConfig extends cdktf.TerraformMetaArguments {
    /**
     * The ID of the monitor to attach the script to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/synthetics_monitor_script.html#monitor_id SyntheticsMonitorScript#monitor_id}
     *
     * @stability stable
     */
    readonly monitorId: string;
    /**
     * The plaintext representing the monitor script.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/synthetics_monitor_script.html#text SyntheticsMonitorScript#text}
     *
     * @stability stable
     */
    readonly text: string;
    /**
     * location block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/synthetics_monitor_script.html#location SyntheticsMonitorScript#location}
     *
     * @stability stable
     */
    readonly location?: SyntheticsMonitorScriptLocation[];
}
/**
 * @stability stable
 */
export interface SyntheticsMonitorScriptLocation {
    /**
     * The HMAC for the monitor script location. Use only one of `hmac` or `vse_password.`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/synthetics_monitor_script.html#hmac SyntheticsMonitorScript#hmac}
     *
     * @stability stable
     */
    readonly hmac?: string;
    /**
     * The monitor script location name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/synthetics_monitor_script.html#name SyntheticsMonitorScript#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The password for the monitor script location used to calculate HMAC. Use only one of `vse_password` or `hmac.`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/synthetics_monitor_script.html#vse_password SyntheticsMonitorScript#vse_password}
     *
     * @stability stable
     */
    readonly vsePassword?: string;
}
export declare function syntheticsMonitorScriptLocationToTerraform(struct?: SyntheticsMonitorScriptLocation): any;
/**
 * Represents a {@link https://www.terraform.io/docs/providers/newrelic/r/synthetics_monitor_script.html newrelic_synthetics_monitor_script}.
 *
 * @stability stable
 */
export declare class SyntheticsMonitorScript extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/newrelic/r/synthetics_monitor_script.html newrelic_synthetics_monitor_script} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: SyntheticsMonitorScriptConfig);
    /**
     * @stability stable
     */
    get id(): string;
    private _monitorId?;
    /**
     * @stability stable
     */
    get monitorId(): string;
    /**
     * @stability stable
     */
    set monitorId(value: string);
    /**
     * @stability stable
     */
    get monitorIdInput(): string | undefined;
    private _text?;
    /**
     * @stability stable
     */
    get text(): string;
    /**
     * @stability stable
     */
    set text(value: string);
    /**
     * @stability stable
     */
    get textInput(): string | undefined;
    private _location?;
    /**
     * @stability stable
     */
    get location(): SyntheticsMonitorScriptLocation[];
    /**
     * @stability stable
     */
    set location(value: SyntheticsMonitorScriptLocation[]);
    /**
     * @stability stable
     */
    resetLocation(): void;
    /**
     * @stability stable
     */
    get locationInput(): SyntheticsMonitorScriptLocation[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
