import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface SyntheticsMonitorConfig extends cdktf.TerraformMetaArguments {
    /**
     * Bypass HEAD request.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/synthetics_monitor.html#bypass_head_request SyntheticsMonitor#bypass_head_request}
     *
     * @stability stable
     */
    readonly bypassHeadRequest?: boolean | cdktf.IResolvable;
    /**
     * The interval (in minutes) at which this monitor should run.
     *
     * Valid values are 1, 5, 10, 15, 30, 60, 360, 720, or 1440.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/synthetics_monitor.html#frequency SyntheticsMonitor#frequency}
     *
     * @stability stable
     */
    readonly frequency: number;
    /**
     * The locations in which this monitor should be run.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/synthetics_monitor.html#locations SyntheticsMonitor#locations}
     *
     * @stability stable
     */
    readonly locations: string[];
    /**
     * The title of this monitor.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/synthetics_monitor.html#name SyntheticsMonitor#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The base threshold for the SLA report.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/synthetics_monitor.html#sla_threshold SyntheticsMonitor#sla_threshold}
     *
     * @stability stable
     */
    readonly slaThreshold?: number;
    /**
     * The monitor status (i.e. ENABLED, MUTED, DISABLED).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/synthetics_monitor.html#status SyntheticsMonitor#status}
     *
     * @stability stable
     */
    readonly status: string;
    /**
     * Fail the monitor check if redirected.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/synthetics_monitor.html#treat_redirect_as_failure SyntheticsMonitor#treat_redirect_as_failure}
     *
     * @stability stable
     */
    readonly treatRedirectAsFailure?: boolean | cdktf.IResolvable;
    /**
     * The monitor type. Valid values are SIMPLE, BROWSER, SCRIPT_BROWSER, and SCRIPT_API.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/synthetics_monitor.html#type SyntheticsMonitor#type}
     *
     * @stability stable
     */
    readonly type: string;
    /**
     * The URI for the monitor to hit.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/synthetics_monitor.html#uri SyntheticsMonitor#uri}
     *
     * @stability stable
     */
    readonly uri?: string;
    /**
     * The string to validate against in the response.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/synthetics_monitor.html#validation_string SyntheticsMonitor#validation_string}
     *
     * @stability stable
     */
    readonly validationString?: string;
    /**
     * Verify SSL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/synthetics_monitor.html#verify_ssl SyntheticsMonitor#verify_ssl}
     *
     * @stability stable
     */
    readonly verifySsl?: boolean | cdktf.IResolvable;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/newrelic/r/synthetics_monitor.html newrelic_synthetics_monitor}.
 *
 * @stability stable
 */
export declare class SyntheticsMonitor extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/newrelic/r/synthetics_monitor.html newrelic_synthetics_monitor} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: SyntheticsMonitorConfig);
    private _bypassHeadRequest?;
    /**
     * @stability stable
     */
    get bypassHeadRequest(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set bypassHeadRequest(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetBypassHeadRequest(): void;
    /**
     * @stability stable
     */
    get bypassHeadRequestInput(): boolean | cdktf.IResolvable | undefined;
    private _frequency?;
    /**
     * @stability stable
     */
    get frequency(): number;
    /**
     * @stability stable
     */
    set frequency(value: number);
    /**
     * @stability stable
     */
    get frequencyInput(): number | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _locations?;
    /**
     * @stability stable
     */
    get locations(): string[];
    /**
     * @stability stable
     */
    set locations(value: string[]);
    /**
     * @stability stable
     */
    get locationsInput(): string[] | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _slaThreshold?;
    /**
     * @stability stable
     */
    get slaThreshold(): number;
    /**
     * @stability stable
     */
    set slaThreshold(value: number);
    /**
     * @stability stable
     */
    resetSlaThreshold(): void;
    /**
     * @stability stable
     */
    get slaThresholdInput(): number | undefined;
    private _status?;
    /**
     * @stability stable
     */
    get status(): string;
    /**
     * @stability stable
     */
    set status(value: string);
    /**
     * @stability stable
     */
    get statusInput(): string | undefined;
    private _treatRedirectAsFailure?;
    /**
     * @stability stable
     */
    get treatRedirectAsFailure(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set treatRedirectAsFailure(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTreatRedirectAsFailure(): void;
    /**
     * @stability stable
     */
    get treatRedirectAsFailureInput(): boolean | cdktf.IResolvable | undefined;
    private _type?;
    /**
     * @stability stable
     */
    get type(): string;
    /**
     * @stability stable
     */
    set type(value: string);
    /**
     * @stability stable
     */
    get typeInput(): string | undefined;
    private _uri?;
    /**
     * @stability stable
     */
    get uri(): string;
    /**
     * @stability stable
     */
    set uri(value: string);
    /**
     * @stability stable
     */
    resetUri(): void;
    /**
     * @stability stable
     */
    get uriInput(): string | undefined;
    private _validationString?;
    /**
     * @stability stable
     */
    get validationString(): string;
    /**
     * @stability stable
     */
    set validationString(value: string);
    /**
     * @stability stable
     */
    resetValidationString(): void;
    /**
     * @stability stable
     */
    get validationStringInput(): string | undefined;
    private _verifySsl?;
    /**
     * @stability stable
     */
    get verifySsl(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set verifySsl(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetVerifySsl(): void;
    /**
     * @stability stable
     */
    get verifySslInput(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
