import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface SyntheticsMultilocationAlertConditionConfig extends cdktf.TerraformMetaArguments {
    /**
     * Set whether to enable the alert condition. Defaults to true.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/synthetics_multilocation_alert_condition.html#enabled SyntheticsMultilocationAlertCondition#enabled}
     *
     * @stability stable
     */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
     * The GUIDs of the Synthetics monitors to alert on.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/synthetics_multilocation_alert_condition.html#entities SyntheticsMultilocationAlertCondition#entities}
     *
     * @stability stable
     */
    readonly entities: string[];
    /**
     * The title of this condition.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/synthetics_multilocation_alert_condition.html#name SyntheticsMultilocationAlertCondition#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The ID of the policy where this condition will be used.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/synthetics_multilocation_alert_condition.html#policy_id SyntheticsMultilocationAlertCondition#policy_id}
     *
     * @stability stable
     */
    readonly policyId: number;
    /**
     * Runbook URL to display in notifications.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/synthetics_multilocation_alert_condition.html#runbook_url SyntheticsMultilocationAlertCondition#runbook_url}
     *
     * @stability stable
     */
    readonly runbookUrl?: string;
    /**
     * The maximum number of seconds a violation can remain open before being closed by the system.
     *
     * Must be one of: 0, 3600, 7200, 14400, 28800, 43200, 86400
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/synthetics_multilocation_alert_condition.html#violation_time_limit_seconds SyntheticsMultilocationAlertCondition#violation_time_limit_seconds}
     *
     * @stability stable
     */
    readonly violationTimeLimitSeconds: number;
    /**
     * critical block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/synthetics_multilocation_alert_condition.html#critical SyntheticsMultilocationAlertCondition#critical}
     *
     * @stability stable
     */
    readonly critical: SyntheticsMultilocationAlertConditionCritical;
    /**
     * warning block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/synthetics_multilocation_alert_condition.html#warning SyntheticsMultilocationAlertCondition#warning}
     *
     * @stability stable
     */
    readonly warning?: SyntheticsMultilocationAlertConditionWarning;
}
/**
 * @stability stable
 */
export interface SyntheticsMultilocationAlertConditionCritical {
    /**
     * The minimum number of monitor locations that must be concurrently failing before a violation is opened.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/synthetics_multilocation_alert_condition.html#threshold SyntheticsMultilocationAlertCondition#threshold}
     *
     * @stability stable
     */
    readonly threshold: number;
}
export declare function syntheticsMultilocationAlertConditionCriticalToTerraform(struct?: SyntheticsMultilocationAlertConditionCriticalOutputReference | SyntheticsMultilocationAlertConditionCritical): any;
/**
 * @stability stable
 */
export declare class SyntheticsMultilocationAlertConditionCriticalOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): SyntheticsMultilocationAlertConditionCritical | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: SyntheticsMultilocationAlertConditionCritical | undefined);
    private _threshold?;
    /**
     * @stability stable
     */
    get threshold(): number;
    /**
     * @stability stable
     */
    set threshold(value: number);
    /**
     * @stability stable
     */
    get thresholdInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface SyntheticsMultilocationAlertConditionWarning {
    /**
     * The minimum number of monitor locations that must be concurrently failing before a violation is opened.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/synthetics_multilocation_alert_condition.html#threshold SyntheticsMultilocationAlertCondition#threshold}
     *
     * @stability stable
     */
    readonly threshold: number;
}
export declare function syntheticsMultilocationAlertConditionWarningToTerraform(struct?: SyntheticsMultilocationAlertConditionWarningOutputReference | SyntheticsMultilocationAlertConditionWarning): any;
/**
 * @stability stable
 */
export declare class SyntheticsMultilocationAlertConditionWarningOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): SyntheticsMultilocationAlertConditionWarning | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: SyntheticsMultilocationAlertConditionWarning | undefined);
    private _threshold?;
    /**
     * @stability stable
     */
    get threshold(): number;
    /**
     * @stability stable
     */
    set threshold(value: number);
    /**
     * @stability stable
     */
    get thresholdInput(): number | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/newrelic/r/synthetics_multilocation_alert_condition.html newrelic_synthetics_multilocation_alert_condition}.
 *
 * @stability stable
 */
export declare class SyntheticsMultilocationAlertCondition extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/newrelic/r/synthetics_multilocation_alert_condition.html newrelic_synthetics_multilocation_alert_condition} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: SyntheticsMultilocationAlertConditionConfig);
    private _enabled?;
    /**
     * @stability stable
     */
    get enabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetEnabled(): void;
    /**
     * @stability stable
     */
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _entities?;
    /**
     * @stability stable
     */
    get entities(): string[];
    /**
     * @stability stable
     */
    set entities(value: string[]);
    /**
     * @stability stable
     */
    get entitiesInput(): string[] | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _policyId?;
    /**
     * @stability stable
     */
    get policyId(): number;
    /**
     * @stability stable
     */
    set policyId(value: number);
    /**
     * @stability stable
     */
    get policyIdInput(): number | undefined;
    private _runbookUrl?;
    /**
     * @stability stable
     */
    get runbookUrl(): string;
    /**
     * @stability stable
     */
    set runbookUrl(value: string);
    /**
     * @stability stable
     */
    resetRunbookUrl(): void;
    /**
     * @stability stable
     */
    get runbookUrlInput(): string | undefined;
    private _violationTimeLimitSeconds?;
    /**
     * @stability stable
     */
    get violationTimeLimitSeconds(): number;
    /**
     * @stability stable
     */
    set violationTimeLimitSeconds(value: number);
    /**
     * @stability stable
     */
    get violationTimeLimitSecondsInput(): number | undefined;
    private _critical;
    /**
     * @stability stable
     */
    get critical(): SyntheticsMultilocationAlertConditionCriticalOutputReference;
    /**
     * @stability stable
     */
    putCritical(value: SyntheticsMultilocationAlertConditionCritical): void;
    /**
     * @stability stable
     */
    get criticalInput(): SyntheticsMultilocationAlertConditionCritical | undefined;
    private _warning;
    /**
     * @stability stable
     */
    get warning(): SyntheticsMultilocationAlertConditionWarningOutputReference;
    /**
     * @stability stable
     */
    putWarning(value: SyntheticsMultilocationAlertConditionWarning): void;
    /**
     * @stability stable
     */
    resetWarning(): void;
    /**
     * @stability stable
     */
    get warningInput(): SyntheticsMultilocationAlertConditionWarning | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
