import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface SyntheticsSecureCredentialConfig extends cdktf.TerraformMetaArguments {
    /**
     * The time the secure credential was created.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/synthetics_secure_credential.html#created_at SyntheticsSecureCredential#created_at}
     *
     * @stability stable
     */
    readonly createdAt?: string;
    /**
     * The secure credential's description.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/synthetics_secure_credential.html#description SyntheticsSecureCredential#description}
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * The secure credential's key name.
     *
     * Regardless of the case used in the configuration, the provider will provide an upcased key to the underlying API.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/synthetics_secure_credential.html#key SyntheticsSecureCredential#key}
     *
     * @stability stable
     */
    readonly key: string;
    /**
     * The time the secure credential was last updated.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/synthetics_secure_credential.html#last_updated SyntheticsSecureCredential#last_updated}
     *
     * @stability stable
     */
    readonly lastUpdated?: string;
    /**
     * The secure credential's value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/synthetics_secure_credential.html#value SyntheticsSecureCredential#value}
     *
     * @stability stable
     */
    readonly value: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/newrelic/r/synthetics_secure_credential.html newrelic_synthetics_secure_credential}.
 *
 * @stability stable
 */
export declare class SyntheticsSecureCredential extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/newrelic/r/synthetics_secure_credential.html newrelic_synthetics_secure_credential} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: SyntheticsSecureCredentialConfig);
    private _createdAt?;
    /**
     * @stability stable
     */
    get createdAt(): string;
    /**
     * @stability stable
     */
    set createdAt(value: string);
    /**
     * @stability stable
     */
    resetCreatedAt(): void;
    /**
     * @stability stable
     */
    get createdAtInput(): string | undefined;
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _key?;
    /**
     * @stability stable
     */
    get key(): string;
    /**
     * @stability stable
     */
    set key(value: string);
    /**
     * @stability stable
     */
    get keyInput(): string | undefined;
    private _lastUpdated?;
    /**
     * @stability stable
     */
    get lastUpdated(): string;
    /**
     * @stability stable
     */
    set lastUpdated(value: string);
    /**
     * @stability stable
     */
    resetLastUpdated(): void;
    /**
     * @stability stable
     */
    get lastUpdatedInput(): string | undefined;
    private _value?;
    /**
     * @stability stable
     */
    get value(): string;
    /**
     * @stability stable
     */
    set value(value: string);
    /**
     * @stability stable
     */
    get valueInput(): string | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
