import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface WorkloadConfig extends cdktf.TerraformMetaArguments {
    /**
     * The New Relic account ID where you want to create the workload.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/workload.html#account_id Workload#account_id}
     *
     * @stability stable
     */
    readonly accountId?: number;
    /**
     * A list of entity GUIDs manually assigned to this workload.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/workload.html#entity_guids Workload#entity_guids}
     *
     * @stability stable
     */
    readonly entityGuids?: string[];
    /**
     * The workload's name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/workload.html#name Workload#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * A list of account IDs that will be used to get entities from.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/workload.html#scope_account_ids Workload#scope_account_ids}
     *
     * @stability stable
     */
    readonly scopeAccountIds?: number[];
    /**
     * entity_search_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/workload.html#entity_search_query Workload#entity_search_query}
     *
     * @stability stable
     */
    readonly entitySearchQuery?: WorkloadEntitySearchQuery[];
}
/**
 * @stability stable
 */
export interface WorkloadEntitySearchQuery {
    /**
     * The query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/workload.html#query Workload#query}
     *
     * @stability stable
     */
    readonly query: string;
}
export declare function workloadEntitySearchQueryToTerraform(struct?: WorkloadEntitySearchQuery): any;
/**
 * Represents a {@link https://www.terraform.io/docs/providers/newrelic/r/workload.html newrelic_workload}.
 *
 * @stability stable
 */
export declare class Workload extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/newrelic/r/workload.html newrelic_workload} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: WorkloadConfig);
    private _accountId?;
    /**
     * @stability stable
     */
    get accountId(): number;
    /**
     * @stability stable
     */
    set accountId(value: number);
    /**
     * @stability stable
     */
    resetAccountId(): void;
    /**
     * @stability stable
     */
    get accountIdInput(): number | undefined;
    /**
     * @stability stable
     */
    get compositeEntitySearchQuery(): string;
    private _entityGuids?;
    /**
     * @stability stable
     */
    get entityGuids(): string[];
    /**
     * @stability stable
     */
    set entityGuids(value: string[]);
    /**
     * @stability stable
     */
    resetEntityGuids(): void;
    /**
     * @stability stable
     */
    get entityGuidsInput(): string[] | undefined;
    /**
     * @stability stable
     */
    get guid(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    /**
     * @stability stable
     */
    get permalink(): string;
    private _scopeAccountIds?;
    /**
     * @stability stable
     */
    get scopeAccountIds(): number[];
    /**
     * @stability stable
     */
    set scopeAccountIds(value: number[]);
    /**
     * @stability stable
     */
    resetScopeAccountIds(): void;
    /**
     * @stability stable
     */
    get scopeAccountIdsInput(): number[] | undefined;
    /**
     * @stability stable
     */
    get workloadId(): number;
    private _entitySearchQuery?;
    /**
     * @stability stable
     */
    get entitySearchQuery(): WorkloadEntitySearchQuery[];
    /**
     * @stability stable
     */
    set entitySearchQuery(value: WorkloadEntitySearchQuery[]);
    /**
     * @stability stable
     */
    resetEntitySearchQuery(): void;
    /**
     * @stability stable
     */
    get entitySearchQueryInput(): WorkloadEntitySearchQuery[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
